@@ -17,6 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <stdlib.h>
 #include <atk/atk.h>
 #include <gtk/gtk.h>
 #include "gail.h"
@@ -139,8 +140,8 @@ gail_select_watcher (GSignalInvocationHint *ihint,
   return TRUE; 
 }
 
-static 
-void gail_focus_tracker_init ()
+static void
+gail_focus_tracker_init ()
 {
   static gboolean  emission_hooks_added = FALSE;
 
@@ -149,8 +150,8 @@ void gail_focus_tracker_init ()
     /*
      * We cannot be sure that the classes exist so we make sure that they do.
      */
-    volatile gpointer dummy1 = gtk_type_class (GTK_TYPE_WIDGET);
-    volatile gpointer dummy2 = gtk_type_class (GTK_TYPE_ITEM);
+    gtk_type_class (GTK_TYPE_WIDGET);
+    gtk_type_class (GTK_TYPE_ITEM);
 
     /*
      * We listen for event_after signal and then check that the
@@ -267,7 +268,19 @@ gtk_module_init(gint *argc, char** argv[])
   atk_registry_set_factory_type (default_registry, GTK_TYPE_OPTION_MENU,
                                  GAIL_TYPE_OPTION_MENU_FACTORY);
 
-  atk_focus_tracker_init (gail_focus_tracker_init);
+  /* LIBGNOMECANVAS SUPPORT */
+  atk_registry_set_factory_type (default_registry, GNOME_TYPE_CANVAS,
+				GAIL_TYPE_CANVAS_FACTORY);
+  atk_registry_set_factory_type (default_registry, GNOME_TYPE_CANVAS_GROUP,
+				 GAIL_TYPE_CANVAS_GROUP_FACTORY);
+  atk_registry_set_factory_type (default_registry, GNOME_TYPE_CANVAS_TEXT,
+				 GAIL_TYPE_CANVAS_TEXT_FACTORY);
+  atk_registry_set_factory_type (default_registry, GNOME_TYPE_CANVAS_RICH_TEXT,
+				 GAIL_TYPE_CANVAS_TEXT_FACTORY);
+  atk_registry_set_factory_type (default_registry, GNOME_TYPE_CANVAS_WIDGET,
+				 GAIL_TYPE_CANVAS_WIDGET_FACTORY);
+
+    atk_focus_tracker_init (gail_focus_tracker_init);
 
   /* Initialize the GailUtility class */
   data = g_type_class_ref (GAIL_TYPE_UTIL);
