@@ -202,6 +202,8 @@ gail_text_cell_new (void)
   cell = GAIL_RENDERER_CELL(object);
 
   cell->renderer = gtk_cell_renderer_text_new ();
+  g_object_ref (cell->renderer);
+  gtk_object_sink (GTK_OBJECT (cell->renderer));
   return atk_object;
 }
 
