@@ -17,6 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <string.h>
 #include <gtk/gtk.h>
 #include "gailwidget.h"
 #include "gailnotebookpage.h"
@@ -30,7 +31,6 @@ static void gail_widget_destroyed                (GtkWidget        *widget,
 static G_CONST_RETURN gchar* gail_widget_get_name (AtkObject *accessible);
 static G_CONST_RETURN gchar* gail_widget_get_description (AtkObject *accessible);
 static AtkObject* gail_widget_get_parent (AtkObject *accessible);
-static AtkRole gail_widget_get_role (AtkObject *accessible);
 static AtkStateSet* gail_widget_ref_state_set (AtkObject *accessible);
 static gint gail_widget_get_index_in_parent (AtkObject *accessible);
 
@@ -108,34 +108,33 @@ gail_widget_get_type (void)
   static GType type = 0;
 
   if (!type)
-  {
-    static const GTypeInfo tinfo =
     {
-      sizeof (GailWidgetClass),
-      (GBaseInitFunc) NULL, /* base init */
-      (GBaseFinalizeFunc) NULL, /* base finalize */
-      (GClassInitFunc) gail_widget_class_init, /* class init */
-      (GClassFinalizeFunc) NULL, /* class finalize */
-      NULL, /* class data */
-      sizeof (GailWidget), /* instance size */
-      0, /* nb preallocs */
-      (GInstanceInitFunc) NULL, /* instance init */
-      NULL /* value table */
-    };
+      static const GTypeInfo tinfo =
+      {
+        sizeof (GailWidgetClass),
+        (GBaseInitFunc) NULL, /* base init */
+        (GBaseFinalizeFunc) NULL, /* base finalize */
+        (GClassInitFunc) gail_widget_class_init, /* class init */
+        (GClassFinalizeFunc) NULL, /* class finalize */
+        NULL, /* class data */
+        sizeof (GailWidget), /* instance size */
+        0, /* nb preallocs */
+        (GInstanceInitFunc) NULL, /* instance init */
+        NULL /* value table */
+      };
 
-    static const GInterfaceInfo atk_component_info =
-    {
+      static const GInterfaceInfo atk_component_info =
+      {
         (GInterfaceInitFunc) atk_component_interface_init,
         (GInterfaceFinalizeFunc) NULL,
         NULL
-    };
+      };
 
-
-    type = g_type_register_static (GTK_TYPE_ACCESSIBLE,
-                                    "GailWidget", &tinfo, 0);
-    g_type_add_interface_static (type, ATK_TYPE_COMPONENT,
-                                 &atk_component_info);
-  }
+      type = g_type_register_static (GTK_TYPE_ACCESSIBLE,
+                                     "GailWidget", &tinfo, 0);
+      g_type_add_interface_static (type, ATK_TYPE_COMPONENT,
+                                   &atk_component_info);
+    }
 
   return type;
 }
@@ -157,7 +156,6 @@ gail_widget_class_init (GailWidgetClass *klass)
   class->get_name = gail_widget_get_name;
   class->get_description = gail_widget_get_description;
   class->get_parent = gail_widget_get_parent;
-  class->get_role = gail_widget_get_role;
   class->ref_state_set = gail_widget_ref_state_set;
   class->get_index_in_parent = gail_widget_get_index_in_parent;
 }
@@ -193,56 +191,55 @@ gail_widget_real_init  (GailWidget *widget,
                         GtkWidget  *gtk_widget)
 {
   GtkAccessible *accessible;
+  AtkObject *obj;
+
+  obj = ATK_OBJECT (widget);
+  obj->layer = ATK_LAYER_WIDGET;
 
   accessible = GTK_ACCESSIBLE (widget);
   accessible->widget = gtk_widget;
   gtk_accessible_connect_widget_destroyed (accessible);
-  g_signal_connect_after (GTK_OBJECT (gtk_widget),
+  g_signal_connect_after (gtk_widget,
                           "focus-in-event",
                           G_CALLBACK (gail_widget_focus_gtk),
                           NULL);
-  g_signal_connect_after (G_OBJECT (gtk_widget),
+  g_signal_connect_after (gtk_widget,
                           "focus-out-event",
                           G_CALLBACK (gail_widget_focus_gtk),
                           NULL);
-  g_signal_connect (G_OBJECT (gtk_widget),
+  g_signal_connect (gtk_widget,
                     "notify",
                     G_CALLBACK (gail_widget_notify_gtk),
                     widget);
-  /*
-   * Support state property change for focus events
-   */
   atk_component_add_focus_handler (ATK_COMPONENT (accessible),
                                    gail_widget_focus_event);
   /*
    * Add signal handlers for GTK signals required to support property changes
    */
-  g_signal_connect (G_OBJECT (gtk_widget),
+  g_signal_connect (gtk_widget,
                     "map",
                     G_CALLBACK (gail_widget_map_gtk),
                     NULL);
-  g_signal_connect (G_OBJECT (gtk_widget),
+  g_signal_connect (gtk_widget,
                     "unmap",
                     G_CALLBACK (gail_widget_map_gtk),
                     NULL);
 }
 
-GtkAccessible* 
+AtkObject* 
 gail_widget_new (GtkWidget *widget)
 {
   GObject *object;
-  GtkAccessible *accessible;
+  AtkObject *accessible;
 
   g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
 
   object = g_object_new (GAIL_TYPE_WIDGET, NULL);
 
-  g_return_val_if_fail (GTK_IS_ACCESSIBLE (object), NULL);
-
   gail_widget_init (GAIL_WIDGET (object), widget);
 
-  accessible = GTK_ACCESSIBLE (object);
-  ATK_OBJECT(accessible)->role = ATK_ROLE_UNKNOWN;
+  accessible = ATK_OBJECT (object);
+  accessible->role = ATK_ROLE_UNKNOWN;
 
   return accessible;
 }
@@ -255,19 +252,18 @@ static void
 gail_widget_connect_widget_destroyed (GtkAccessible *accessible)
 {
   if (accessible->widget)
-  {
-    g_signal_connect (G_OBJECT (accessible->widget),
-                      "destroy",
-                      G_CALLBACK (gail_widget_destroyed),
-                      accessible);
-  }
+    {
+      g_signal_connect (accessible->widget,
+                        "destroy",
+                        G_CALLBACK (gail_widget_destroyed),
+                        accessible);
+    }
 }
 
 /*
  * This function is called when the widget is destroyed.
  * It sets the widget field in the GtkAccessible structure to NULL
- * and signals a property change event for "accessible-state" with
- * the new state being ATK_STATE_DEFUNCT
+ * and emits a tate-change signal for the state ATK_STATE_DEFUNCT
  */
 static void 
 gail_widget_destroyed (GtkWidget     *widget,
@@ -281,61 +277,53 @@ static G_CONST_RETURN gchar*
 gail_widget_get_name (AtkObject *accessible)
 {
   if (accessible->name)
-  {
     return accessible->name;
-  }
   else
-  {
-    /*
-     * Get the widget name is it exists
-     */
-    GtkWidget* widget = GTK_ACCESSIBLE (accessible)->widget;
-
-    if (widget == NULL)
     {
       /*
-       * State is defunct
+       * Get the widget name is it exists
        */
-      return NULL;
-    }
-    g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
+      GtkWidget* widget = GTK_ACCESSIBLE (accessible)->widget;
 
-    return widget->name;
-  }
+      if (widget == NULL)
+        /*
+         * State is defunct
+         */
+        return NULL;
+
+      g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
+
+      return widget->name;
+    }
 }
 
 static G_CONST_RETURN gchar*
 gail_widget_get_description (AtkObject *accessible)
 {
   if (accessible->description)
-  {
     return accessible->description;
-  }
   else
-  {
-    /* Get the tooltip from the widget */
-    GtkAccessible *obj = GTK_ACCESSIBLE (accessible);
-    GtkTooltipsData *data;
-
-    g_return_val_if_fail (obj, NULL);
-
-    if (obj->widget == NULL)
-    {
-      /*
-       * Object is defunct
-       */
-      return NULL;
-    }
-    g_return_val_if_fail (GTK_WIDGET (obj->widget), NULL);
-    
-    data = gtk_tooltips_data_get(obj->widget);
-    if (data == NULL)
     {
+      /* Get the tooltip from the widget */
+      GtkAccessible *obj = GTK_ACCESSIBLE (accessible);
+      GtkTooltipsData *data;
+
+      g_return_val_if_fail (obj, NULL);
+
+      if (obj->widget == NULL)
+        /*
+         * Object is defunct
+         */
+        return NULL;
+ 
+      g_return_val_if_fail (GTK_WIDGET (obj->widget), NULL);
+    
+      data = gtk_tooltips_data_get (obj->widget);
+      if (data == NULL)
         return NULL;
-    }
 
-    return data->tip_text;
-  }
+      return data->tip_text;
+    }
 }
 
 static AtkObject* 
@@ -346,36 +334,27 @@ gail_widget_get_parent (AtkObject *accessible)
   parent = accessible->accessible_parent;
 
   if (parent != NULL)
-  {
     g_return_val_if_fail (ATK_IS_OBJECT (parent), NULL);
-  }
   else
-  {
-    GtkWidget *widget, *parent_widget;
-
-    widget = GTK_ACCESSIBLE (accessible)->widget;
-    if (widget == NULL)
     {
-      /*
-       * State is defunct
-       */
-      return NULL;
+      GtkWidget *widget, *parent_widget;
+
+      widget = GTK_ACCESSIBLE (accessible)->widget;
+      if (widget == NULL)
+        /*
+         * State is defunct
+         */
+        return NULL;
+
+      parent_widget = widget->parent;
+      if (parent_widget == NULL)
+        return NULL;
+
+      parent = gtk_widget_get_accessible (parent_widget);
     }
-    parent_widget = widget->parent;
-    if (parent_widget == NULL)
-      return NULL;
-
-    parent = gtk_widget_get_accessible (parent_widget);
-  }
   return parent;
 }
 
-static AtkRole 
-gail_widget_get_role (AtkObject *accessible)
-{
-  return accessible->role;
-}
-
 static AtkStateSet*
 gail_widget_ref_state_set (AtkObject *accessible)
 {
@@ -385,58 +364,58 @@ gail_widget_ref_state_set (AtkObject *accessible)
   state_set = ATK_OBJECT_CLASS (parent_class)->ref_state_set (accessible);
 
   if (widget == NULL)
-  {
-    atk_state_set_add_state (state_set, ATK_STATE_DEFUNCT);
-  }
+    {
+      atk_state_set_add_state (state_set, ATK_STATE_DEFUNCT);
+    }
   else
-  {
-    if (GTK_WIDGET_IS_SENSITIVE (widget))
     {
-      atk_state_set_add_state (state_set, ATK_STATE_SENSITIVE);
-    }
-  
-    if (GTK_WIDGET_CAN_FOCUS (widget))
-    {
-      atk_state_set_add_state (state_set, ATK_STATE_FOCUSABLE);
-    }
-    /*
-     * We do not currently generate notifications when an ATK object 
-     * corresponding to a GtkWidget changes visibility by being scrolled 
-     * on or off the screen.  The testcase for this is the main window 
-     * of the testgtk application in which a set of buttons in a GtkVBox 
-     * is in a scrooled window with a viewport.
-     *
-     * To generate the notifications we would need to do the following: 
-     * 1) Find the GtkViewPort among the antecendents of the objects
-     * 2) Create an accesible for the GtkViewPort
-     * 3) Connect to the value-changed signal on the viewport
-     * 4) When the signal is received we need to traverse the children 
-     * of the viewport and check whether the children are visible or not 
-     * visible; we may want to restrict this to the widgets for which 
-     * accessible objects have been created.
-     * 5) We probably need to store a variable on_screen in the 
-     * GailWidget data structure so we can determine whether the value has 
-     * changed.
-     */
-    if (gail_widget_on_screen (widget))
-    {
-      if (GTK_WIDGET_VISIBLE (widget))
-      {
-        atk_state_set_add_state (state_set, ATK_STATE_VISIBLE);
-
-        if (GTK_WIDGET_MAPPED (widget))
+      if (GTK_WIDGET_IS_SENSITIVE (widget))
         {
-          atk_state_set_add_state (state_set, ATK_STATE_SHOWING);
+          atk_state_set_add_state (state_set, ATK_STATE_SENSITIVE);
         }
-      }
-    }
+  
+      if (GTK_WIDGET_CAN_FOCUS (widget))
+        {
+          atk_state_set_add_state (state_set, ATK_STATE_FOCUSABLE);
+        }
+      /*
+       * We do not currently generate notifications when an ATK object 
+       * corresponding to a GtkWidget changes visibility by being scrolled 
+       * on or off the screen.  The testcase for this is the main window 
+       * of the testgtk application in which a set of buttons in a GtkVBox 
+       * is in a scrooled window with a viewport.
+       *
+       * To generate the notifications we would need to do the following: 
+       * 1) Find the GtkViewPort among the antecendents of the objects
+       * 2) Create an accesible for the GtkViewPort
+       * 3) Connect to the value-changed signal on the viewport
+       * 4) When the signal is received we need to traverse the children 
+       * of the viewport and check whether the children are visible or not 
+       * visible; we may want to restrict this to the widgets for which 
+       * accessible objects have been created.
+       * 5) We probably need to store a variable on_screen in the 
+       * GailWidget data structure so we can determine whether the value has 
+       * changed.
+       */
+      if (gail_widget_on_screen (widget))
+        {
+          if (GTK_WIDGET_VISIBLE (widget))
+            {
+              atk_state_set_add_state (state_set, ATK_STATE_VISIBLE);
 
-    if (GTK_WIDGET_HAS_FOCUS (widget))
-    {
-      atk_state_set_add_state (state_set, ATK_STATE_FOCUSED);
+              if (GTK_WIDGET_MAPPED (widget))
+                {
+                  atk_state_set_add_state (state_set, ATK_STATE_SHOWING);
+                }
+            }
+        }
+  
+      if (GTK_WIDGET_HAS_FOCUS (widget))
+        {
+          atk_state_set_add_state (state_set, ATK_STATE_FOCUSED);
+        }
+      atk_state_set_add_state (state_set, ATK_STATE_ENABLED);
     }
-    atk_state_set_add_state (state_set, ATK_STATE_ENABLED);
-  }
   return state_set;
 }
 
@@ -448,36 +427,35 @@ gail_widget_get_index_in_parent (AtkObject *accessible)
   GList *children, *tmp_list;
 
   if (accessible->accessible_parent)
-  {
-    if (GAIL_IS_NOTEBOOK_PAGE (accessible->accessible_parent))
-      return 0;
-  }
+    {
+      if (GAIL_IS_NOTEBOOK_PAGE (accessible->accessible_parent))
+        return 0;
+    }
 
   widget = GTK_ACCESSIBLE (accessible)->widget;
 
   if (widget == NULL)
-  {
     /*
      * State is defunct
      */
     return -1;
-  }
+
   parent_widget = widget->parent;
   g_return_val_if_fail (GTK_IS_CONTAINER (parent_widget), -1);
 
   tmp_list = children = gtk_container_children (GTK_CONTAINER (parent_widget));
 
   while (tmp_list)
-  {
-    if (GTK_WIDGET (tmp_list->data) == widget)
     {
+      if (GTK_WIDGET (tmp_list->data) == widget)
+        {
+          index++;
+          g_list_free (children);
+          return index;
+        }
+      tmp_list = g_list_next (tmp_list);
       index++;
-      g_list_free (children);
-      return index;
     }
-    tmp_list = g_list_next (tmp_list);
-    index++;
-  }
   g_list_free (children);
   return -1;  
 }
@@ -490,6 +468,8 @@ atk_component_interface_init (AtkComponentIface *iface)
   /*
    * Use default implementation for contains and get_position
    */
+  iface->contains = NULL;
+  iface->get_position = NULL;
   iface->add_focus_handler = gail_widget_add_focus_handler;
   iface->get_extents = gail_widget_get_extents;
   iface->get_size = gail_widget_get_size;
@@ -525,80 +505,67 @@ gail_widget_get_extents (AtkComponent   *component,
   GtkWidget *widget = GTK_ACCESSIBLE (component)->widget;
 
   if (widget == NULL)
-  {
     /*
      * Object is defunct
      */
     return;
-  }
 
   *width = widget->allocation.width;
   *height = widget->allocation.height;
   if (!gail_widget_on_screen (widget) || (!GTK_WIDGET_DRAWABLE (widget)))
-  {
-    *x = G_MININT;
-    *y = G_MININT;
-    return;
-  }
+    {
+      *x = G_MININT;
+      *y = G_MININT;
+      return;
+    }
 
   if (widget->parent)
-  {
-    window = gtk_widget_get_parent_window(widget);
-  }
+    window = gtk_widget_get_parent_window (widget);
   else
-  {
     window = widget->window;
-  }
-  {
-    int x, y, width, height, depth;
-    gdk_window_get_position (window, &x, &y);
-    gdk_window_get_geometry (window, &x, &y, &width, &height, &depth);
-  }
-  gdk_window_get_origin(window, &x_parent, &y_parent);
-  window = gdk_window_get_toplevel(widget->window);
-  gdk_window_get_origin(window, &x_toplevel, &y_toplevel);
+   
+  gdk_window_get_origin (window, &x_parent, &y_parent);
 
-  if (coord_type == ATK_XY_SCREEN) 
-  { 
-    *x = widget->allocation.x + x_parent;
-    *y = widget->allocation.y + y_parent;
-  }
-  else if (coord_type == ATK_XY_WINDOW) 
-  { 
-    *x = widget->allocation.x + (x_parent - x_toplevel);
-    *y = widget->allocation.y + (y_parent - y_toplevel);
-  }
+  *x = widget->allocation.x + x_parent;
+  *y = widget->allocation.y + y_parent;
+ 
+ if (coord_type == ATK_XY_WINDOW) 
+    { 
+      window = gdk_window_get_toplevel (widget->window);
+      gdk_window_get_origin (window, &x_toplevel, &y_toplevel);
+      *x -= x_toplevel;
+      *y -= y_toplevel;
+    }
 }
 
 static void 
-gail_widget_get_size    (AtkComponent   *component,
-                         gint           *width,
-                         gint           *height)
+gail_widget_get_size (AtkComponent   *component,
+                      gint           *width,
+                      gint           *height)
 {
   GtkWidget *widget = GTK_ACCESSIBLE (component)->widget;
 
   if (widget == NULL)
-  {
     /*
      * Object is defunct
      */
     return;
-  }
+
   *width = widget->allocation.width;
   *height = widget->allocation.height;
 }
 
 static gboolean 
-gail_widget_grab_focus(AtkComponent   *component)
+gail_widget_grab_focus (AtkComponent   *component)
 {
   GtkWidget *widget = GTK_ACCESSIBLE (component)->widget;
 
   g_return_val_if_fail (widget != NULL, FALSE);
-  if (GTK_WIDGET_CAN_FOCUS(widget))
-  {
-    gtk_widget_grab_focus (widget);
-    return TRUE;
-  }
+  if (GTK_WIDGET_CAN_FOCUS (widget))
+    {
+      gtk_widget_grab_focus (widget);
+      return TRUE;
+    }
   else
     return FALSE;
 }
@@ -607,7 +574,7 @@ static void
 gail_widget_remove_focus_handler (AtkComponent   *component,
                                   guint          handler_id)
 {
-  g_signal_handler_disconnect (ATK_OBJECT (component), handler_id);
+  g_signal_handler_disconnect (component, handler_id);
 }
 
 static gboolean 
@@ -621,100 +588,99 @@ gail_widget_set_extents (AtkComponent   *component,
   GtkWidget *widget = GTK_ACCESSIBLE (component)->widget;
 
   if (widget == NULL)
-  {
-    /*gtkwindow.c
+    /*
      * Object is defunct
      */
     return FALSE;
-  }
-  if (GTK_WIDGET_TOPLEVEL(widget))
-  {
-    if (coord_type == ATK_XY_WINDOW)
+
+  if (GTK_WIDGET_TOPLEVEL (widget))
     {
-      gint x_current, y_current;
-      GdkWindow *window = widget->window;
-      gdk_window_get_origin(window, &x_current, &y_current);
-      x_current += x;
-      y_current += y;
-      if (x_current < 0 || y_current < 0)
-        return FALSE;
-      else
-      {
-        gtk_widget_set_uposition (widget, x_current, y_current);
-        gtk_widget_set_usize (widget, width, height);
-        return TRUE;
-      }
+      if (coord_type == ATK_XY_WINDOW)
+        {
+          gint x_current, y_current;
+          GdkWindow *window = widget->window;
+
+          gdk_window_get_origin (window, &x_current, &y_current);
+          x_current += x;
+          y_current += y;
+          if (x_current < 0 || y_current < 0)
+            return FALSE;
+          else
+            {
+              gtk_widget_set_uposition (widget, x_current, y_current);
+              gtk_widget_set_usize (widget, width, height);
+              return TRUE;
+            }
+        }
+      else if (coord_type == ATK_XY_SCREEN)
+        {  
+          gtk_widget_set_uposition (widget, x, y);
+          gtk_widget_set_usize (widget, width, height);
+          return TRUE;
+        }
     }
-    else if (coord_type == ATK_XY_SCREEN)
-    {  
-      gtk_widget_set_uposition (widget, x, y);
-      gtk_widget_set_usize (widget, width, height);
-      return TRUE;
-    }
-  }
   return FALSE;
 }
 
 static gboolean
-gail_widget_set_position(AtkComponent   *component,
-                         gint           x,
-                         gint           y,
-                         AtkCoordType   coord_type)
+gail_widget_set_position (AtkComponent   *component,
+                          gint           x,
+                          gint           y,
+                          AtkCoordType   coord_type)
 {
   GtkWidget *widget = GTK_ACCESSIBLE (component)->widget;
 
   if (widget == NULL)
-  {
     /*
      * Object is defunct
      */
     return FALSE;
-  }
-  if (GTK_WIDGET_TOPLEVEL(widget))
-  {
-    if (coord_type == ATK_XY_WINDOW)
+
+  if (GTK_WIDGET_TOPLEVEL (widget))
     {
-      gint x_current, y_current;
-      GdkWindow *window = widget->window;
-      gdk_window_get_origin(window, &x_current, &y_current);
-      x_current += x;
-      y_current += y;
-      if (x_current < 0 || y_current < 0)
-        return FALSE;
-      else
-      {
-        gtk_widget_set_uposition (widget, x_current, y_current);
-        return TRUE;
-      }
+      if (coord_type == ATK_XY_WINDOW)
+        {
+          gint x_current, y_current;
+          GdkWindow *window = widget->window;
+
+          gdk_window_get_origin (window, &x_current, &y_current);
+          x_current += x;
+          y_current += y;
+          if (x_current < 0 || y_current < 0)
+            return FALSE;
+          else
+            {
+              gtk_widget_set_uposition (widget, x_current, y_current);
+              return TRUE;
+            }
+        }
+      else if (coord_type == ATK_XY_SCREEN)
+        {  
+          gtk_widget_set_uposition (widget, x, y);
+          return TRUE;
+        }
     }
-    else if (coord_type == ATK_XY_SCREEN)
-    {  
-      gtk_widget_set_uposition (widget, x, y);
-      return TRUE;
-    }
-  }
   return FALSE;
 }
 
 static gboolean 
-gail_widget_set_size    (AtkComponent   *component,
-                         gint           width,
-                         gint           height)
+gail_widget_set_size (AtkComponent   *component,
+                      gint           width,
+                      gint           height)
 {
   GtkWidget *widget = GTK_ACCESSIBLE (component)->widget;
 
   if (widget == NULL)
-  {
     /*
      * Object is defunct
      */
     return FALSE;
-  }
-  if (GTK_WIDGET_TOPLEVEL(widget))
-  {
-    gtk_widget_set_usize (widget, width, height);
-    return TRUE;
-  }
+
+  if (GTK_WIDGET_TOPLEVEL (widget))
+    {
+      gtk_widget_set_usize (widget, width, height);
+      return TRUE;
+    }
   else
    return FALSE;
 }
@@ -739,7 +705,6 @@ _gail_widget_get_parent (GtkWidget* widget)
 }
 #endif
 
-
 /*
  * This function is a signal handler for notify_in_event and focus_out_event
  * signal which gets emitted on a GtkWidget.
@@ -850,11 +815,6 @@ gail_widget_real_notify_gtk (GObject     *obj,
   atk_object_notify_state_change (atk_obj, state, value);
 }
 
-/*
- * This function is the signal handler defined for focus event on
- * AtkObject by the property change mechanism so that we get a
- * property change for accessible-state when focus changes.
- */
 static void 
 gail_widget_focus_event (AtkObject   *obj,
                          gboolean    focus_in)
@@ -879,18 +839,17 @@ gail_widget_focus_event (AtkObject   *obj,
  * widgets top-level window.
  **/
 void
-gail_widget_get_origins(GtkWidget	*widget,
-                             gint	*x_widget,
-                             gint	*y_widget,
-                             gint	*x_window,
-                             gint	*y_window)
+gail_widget_get_origins (GtkWidget *widget,
+                         gint      *x_widget,
+                         gint      *y_widget,
+                         gint      *x_window,
+                         gint      *y_window)
 {
   GdkWindow *window;
 
-  gdk_window_get_origin(GDK_WINDOW(widget->window),
-    x_widget, y_widget);
-  window = gdk_window_get_toplevel(GDK_WINDOW(widget->window));
-  gdk_window_get_origin(window, x_window, y_window);
+  gdk_window_get_origin (widget->window, x_widget, y_widget);
+  window = gdk_window_get_toplevel (widget->window);
+  gdk_window_get_origin (window, x_window, y_window);
 }
 
 static GtkWidget*
@@ -903,11 +862,11 @@ gail_widget_find_viewport (GtkWidget *widget)
 
   parent = widget->parent;
   while (parent != NULL)
-  {
-    if (GTK_IS_VIEWPORT (parent))
-      break;
-    parent = parent->parent;
-  }
+    {
+      if (GTK_IS_VIEWPORT (parent))
+        break;
+      parent = parent->parent;
+    }
   return parent;
 }
 
@@ -923,32 +882,27 @@ static gboolean gail_widget_on_screen (GtkWidget *widget)
 
   viewport = gail_widget_find_viewport (widget);
   if (viewport)
-  {
-    GtkAdjustment *adjustment;
-    GdkRectangle visible_rect;
+    {
+      GtkAdjustment *adjustment;
+      GdkRectangle visible_rect;
 
-    adjustment = gtk_viewport_get_vadjustment (GTK_VIEWPORT (viewport));
-    visible_rect.y = adjustment->value;
-    adjustment = gtk_viewport_get_hadjustment (GTK_VIEWPORT (viewport));
-    visible_rect.x = adjustment->value;
-    visible_rect.width = viewport->allocation.width;
-    visible_rect.height = viewport->allocation.height;
+      adjustment = gtk_viewport_get_vadjustment (GTK_VIEWPORT (viewport));
+      visible_rect.y = adjustment->value;
+      adjustment = gtk_viewport_get_hadjustment (GTK_VIEWPORT (viewport));
+      visible_rect.x = adjustment->value;
+      visible_rect.width = viewport->allocation.width;
+      visible_rect.height = viewport->allocation.height;
              
-    if (((widget->allocation.x + widget->allocation.width) < visible_rect.x) ||
-       ((widget->allocation.y + widget->allocation.height) < visible_rect.y) ||
-       (widget->allocation.x > (visible_rect.x + visible_rect.width)) ||
-       (widget->allocation.y > (visible_rect.y + visible_rect.height)))
-    {
-      return_value = FALSE;
+      if (((widget->allocation.x + widget->allocation.width) < visible_rect.x) ||
+         ((widget->allocation.y + widget->allocation.height) < visible_rect.y) ||
+         (widget->allocation.x > (visible_rect.x + visible_rect.width)) ||
+         (widget->allocation.y > (visible_rect.y + visible_rect.height)))
+        return_value = FALSE;
+      else
+        return_value = TRUE;
     }
-    else
-    {
-      return_value = TRUE;
-    }
-  }
   else
-  {
     return_value = TRUE;
-  }
+
   return return_value;
 }
