@@ -711,11 +711,10 @@ _print_relation (AtkObject *aobject)
 
         for (i = 0; i < n_relations; i++)
           {
-            relation = atk_relation_set_get_relation(
-              relation_set, i);
+            relation = atk_relation_set_get_relation (relation_set, i);
 
             relation_type = atk_relation_get_relation_type (relation);
-            relation_name = get_relation_name(relation_type);
+            relation_name = atk_relation_type_get_name (relation_type);
 
             relation_arry = atk_relation_get_target(relation);
 
@@ -772,9 +771,10 @@ _print_state (AtkObject *aobject)
       {
         ATK_STATE_ACTIVE,
         ATK_STATE_CHECKED,
-        ATK_STATE_COLLAPSED,
+        ATK_STATE_EXPANDED,
         ATK_STATE_EXPANDABLE,
         ATK_STATE_SELECTED,
+        ATK_STATE_SHOWING,
         ATK_STATE_VISIBLE
       };
 
@@ -1969,7 +1969,8 @@ _print_key_value(TabNumber tab_n, gint group_number,
         }
       else
         {
-          g_print("\t%-30s\t%s\n", label, (gchar *)value);
+          g_print("\t%-30s\t%s\n", label, 
+                  value ? (gchar *)value : "NULL");
         }
     }
 
@@ -2410,11 +2411,12 @@ static void _property_change_handler (AtkObject *obj,
 
     if (top_tab == OBJECT &&
        ((strcmp (values->property_name, "accessible-name") == 0) ||
-        (strcmp (values->property_name, "accessible-state") == 0) ||
         (strcmp (values->property_name, "accessible-description") == 0) ||
         (strcmp (values->property_name, "accessible-parent") == 0) ||
         (strcmp (values->property_name, "accessible-value") == 0) ||
         (strcmp (values->property_name, "accessible-role") == 0) ||
+        (strcmp (values->property_name, "accessible-component-layout") == 0) ||
+        (strcmp (values->property_name, "accessible-component-mdi-zorder") == 0) ||
         (strcmp (values->property_name, "accessible-table-caption") == 0) ||
         (strcmp (values->property_name,
                  "accessible-table-column-description") == 0) ||
