@@ -1,3 +1,4 @@
+#include <string.h>
 #include <stdlib.h>
 #include "testtextlib.h"
 
@@ -491,12 +492,16 @@ _selection_tests(AtkObject *obj)
   selection_count = atk_selection_get_selection_count(ATK_SELECTION(obj));
   g_print("atk_selection_get_selection_count returns %d\n", selection_count);
 
-  /* Select row 2 and then unselect it */
   if (atk_table_is_row_selected(table, 2))
   {
-    g_print("atk_table_is_row_selected(obj, 2) returns TRUE\n");
+    g_print("atk_table_is_row_selected (table, 2) returns TRUE\n");
+    atk_selection_clear_selection (ATK_SELECTION (obj));
     if (atk_table_add_row_selection(table, 4))
       g_print("atk_table_add_row_selection: selected row 4\n");
+    if (!atk_table_is_row_selected (table, 4))
+      g_print("atk_table_is_row_selected returns false for row 2\n");
+    if (atk_table_is_row_selected (table, 2))
+      g_print("atk_table_is_row_selected gives false positive for row 2\n");
   }
 
   if (atk_table_is_row_selected(table, 3))
@@ -516,6 +521,7 @@ _selection_tests(AtkObject *obj)
     g_print("atk_table_is_column_selected(obj, 2) returns TRUE\n");
     if (atk_table_add_column_selection(table, 4))
       g_print("atk_table_add_column_selection: selected column 4\n");
+    g_print("atk_table_is_column_selected(obj, 2) returns TRUE\n");
   }
 
   if (atk_table_is_column_selected(table, 3))
@@ -534,7 +540,7 @@ _create_event_watcher ()
 int
 gtk_module_init(gint argc, char* argv[])
 {
-    g_print("testtable Module loaded\n");
+    g_print("TestTable Module loaded\n");
 
     _create_event_watcher();
 
@@ -650,8 +656,9 @@ static void _property_signal_connect (AtkObject *obj)
   }
 }
 
-static void _property_change_handler (AtkObject *obj,
-  AtkPropertyValues *values)
+static void 
+_property_change_handler (AtkObject         *obj,
+                          AtkPropertyValues *values)
 {
   gchar *obj_text;
   const gchar *name;
@@ -659,9 +666,13 @@ static void _property_change_handler (AtkObject *obj,
   if (g_table != NULL)
   {
     gint index = atk_object_get_index_in_parent(obj);
-    g_print("Index is %d, row is %d, col is %d\n", index,
-      atk_table_get_row_at_index(g_table, index),
-      atk_table_get_column_at_index(g_table, index));
+    
+    if (index >= 0)
+      g_print("Index is %d, row is %d, col is %d\n", index,
+              atk_table_get_row_at_index(g_table, index),
+              atk_table_get_column_at_index(g_table, index));
+    else
+      g_print ("index: %d for %s\n", index, g_type_name (G_OBJECT_TYPE (obj)));
   }
 
   if (ATK_IS_TEXT(obj))
@@ -684,18 +695,7 @@ static void _property_change_handler (AtkObject *obj,
     switch (old_type)
     {
     case G_TYPE_INT:
-      if (strcmp (values->property_name, "accessible-state") == 0)
-      {
-        name = atk_state_type_get_name (g_value_get_int (&values->old_value));
-        if (name != NULL)
-          g_print ("value was <%s>\n", name);
-        else
-          g_print ("value was <NULL>\n");
-      }
-      else
-      {
-        g_print("value was <%d>\n", g_value_get_int (&values->old_value));
-      }
+      g_print("value was <%d>\n", g_value_get_int (&values->old_value));
       break;
     case G_TYPE_STRING:
       name = g_value_get_string (&values->old_value);
@@ -721,18 +721,7 @@ static void _property_change_handler (AtkObject *obj,
     switch (new_type)
     {
     case G_TYPE_INT:
-      if (strcmp (values->property_name, "accessible-state") == 0)
-      {
-        name = atk_state_type_get_name (g_value_get_int (&values->new_value));
-        if (name != NULL)
-          g_print ("value is <%s>\n", name);
-        else
-          g_print ("value is <NULL>\n");
-      }
-      else
-      {
-        g_print("value is <%d>\n", g_value_get_int (&values->new_value));
-      }
+      g_print("value is <%d>\n", g_value_get_int (&values->new_value));
       break;
     case G_TYPE_STRING:
       name = g_value_get_string (&values->new_value);
